@@ -1,7 +1,8 @@
 /*
  * This file was part of gggl, it implements a variety of pixel conversion
  * functions that are usable with babl, the file needs more cleanup, and
- * doesn't return the number of samples processed as a long, like it's supposed to.
+ * doesn't return the number of samples processed as a long, like it's
+ * supposed to.
  *
  *    GGGL is free software; you can redistribute it and/or modify
  *    it under the terms of the GNU General Public License as published by
@@ -22,13 +23,16 @@
  *  Copyright 2003, 2004, 2005 Øyvind Kolås <pippin@gimp.org>
  */
 
+#include "config.h"
+
+#include <math.h>
+#include <string.h>
+
 #include "babl.h"
 
+
 #define INLINE    inline
 
-#include <math.h>
-#include <stdio.h>
-#include <string.h>
 
 /*
  * Implemented according to information read from:
@@ -64,20 +68,21 @@ static int table_inited = 0;
 static void
 table_init (void)
 {
+  int i;
+
   if (table_inited)
     return;
   table_inited = 1;
 
   /* fill tables for conversion from integer to float */
-  {
-    int i;
-    for (i = 0; i < 1 << 8; i++)
-      {
-        table_8_F[i] = (i * 1.0) / 255.0;
-      }
-    for (i = 0; i < 1 << 16; i++)
+  for (i = 0; i < 1 << 8; i++)
+    {
+      table_8_F[i] = (i * 1.0) / 255.0;
+    }
+  for (i = 0; i < 1 << 16; i++)
+    {
       table_16_F[i] = (i * 1.0) / 65535.0;
-  }
+    }
   /* fill tables for conversion from float to integer */
   {
     union
@@ -89,11 +94,13 @@ table_init (void)
 
     u.s[0] = 0.0;
 
-    for (u.s[1] = 0; u.s[1] < 65535; u.s[1] += 1)
+    for (i = 0; i < 1 << 16; i++)
       {
         unsigned char  c;
         unsigned short s;
 
+        u.s[1] = i;
+
         if (u.f <= 0.0)
           {
             c = 0;
